@@ -19,40 +19,41 @@ def gtf_to_gene_info(gtf_file):
     fout.close()
 
 
-def annotation_snp_pos(res_file, bed_file, p_cut=None):
+def annotation_snp_pos(res_file, bed_file, p_cut=1, dis=0):
     """
-    注释互作检验的SNP信息
-    :param res_file: 互作检验结果文件，前两列是互作SNP对的顺序编号，最后一列是P值
-    :param bed_file: plink文件
-    :param p_cut: P阈值
-    :return:
+    add the snp information for the epistasis result file; select top significant SNP pairs based on p cut value;
+    select SNP pairs bases on their distance.
+    :param res_file: The result file for epistasis file. The first two columns are the orders for the SNP pairs, and
+    the last column is the p values.
+    :param bed_file: the prefix for the plink binary file
+    :param p_cut: p cut value, default value is 1.
+    :param dis: the min distance between SNP pairs, the default value is -1.
+    :return: 0
     """
     snp_info = {}
     order = -1
-    fin = open(bed_file + '.bim')
-    for line in fin:
-        order += 1
+    with open(bed_file, 'r') as fin:
+        for line in fin:
+            order += 1
+            arr = line.split()
+            snp_info[str(order)] = ' '.join(arr)
+    with open(res_file, 'r') as fin, open(res_file + '.anno', 'w') as fout:
+        line = fin.readline()
         arr = line.split()
-        snp_info[str(order)] = ' '.join(arr)
-    fin.close()
-    fout = open(res_file + '.anno', 'w')
-    fin = open(res_file)
-    line = fin.readline()
-    arr = line.split()
-    fout.write(' '.join([arr[0], 'snp0_chr', 'snp0_ID', 'snp0_cm', 'snp0_bp', 'snp0_allele1', 'snp0_allele2',
+        fout.write(' '.join([arr[0], 'snp0_chr', 'snp0_ID', 'snp0_cm', 'snp0_bp', 'snp0_allele1', 'snp0_allele2',
                          arr[1], 'snp1_chr', 'snp1_ID', 'snp1_cm', 'snp1_bp', 'snp1_allele1', 'snp1_allele2']))
-    fout.write(' ')
-    fout.write(' '.join(arr[2:]))
-    fout.write('\n')
-    for line in fin:
-        arr = line.split()
-        if p_cut is None or float(arr[-1]) < p_cut:
-            fout.write(' '.join([arr[0], snp_info[arr[0]], arr[1], snp_info[arr[1]]]))
-            fout.write(' ')
-            fout.write(' '.join(arr[2:]))
-            fout.write('\n')
-    fin.close()
-    fout.close()
+        fout.write(' ')
+        fout.write(' '.join(arr[2:]))
+        fout.write('\n')
+        for line in fin:
+            arr = line.split()
+            snp0 = snp_info[arr[0]].split()
+            snp1 = snp_info[arr[1]].split()
+            if float(arr[-1]) <= p_cut and (snp0[0] != snp1[0] or abs(float(snp0[3]) - float(snp1[3])) > dis):
+                fout.write(' '.join([arr[0], snp_info[arr[0]], arr[1], snp_info[arr[1]]]))
+                fout.write(' ')
+                fout.write(' '.join(arr[2:]))
+                fout.write('\n')
     return 0
 
 
