@@ -1,4 +1,4 @@
 from gmat.remma.remma_cpu.remma_epiAA_cpu.remma_epiAA_cpu import remma_epiAA_cpu, remma_epiAA_cpu_parallel
 from gmat.remma.remma_cpu.remma_epiAA_cpu.remma_epiAA_pair_cpu import remma_epiAA_pair_cpu
-from gmat.remma.remma_cpu.remma_epiAA_cpu.remma_epiAA_eff_cpu_c import remma_epiAA_eff_cpu_c
+from gmat.remma.remma_cpu.remma_epiAA_cpu.remma_epiAA_eff_cpu_c import remma_epiAA_eff_cpu_c, remma_epiAA_eff_cpu_c_parallel
 
